@@ -5,13 +5,24 @@ class Syllabification:
     __vowels = 'aeiouáéíóúäëïöüàèìòùAEIOUÁÉÍÓÚÄËÏÓÜÀÈÌÒÙ'
     __close = 'iuIU'
 
-    def __init__(self, word, exceptions=True, ipa=False, h = False):
+    def __init__(self, word, exceptions=1, ipa=False, h = False, epen = False,
+                 tl = False):
         self.__ipa = ipa
         self.__h = h
+        if tl:
+            self.__tl = True
+        else:
+            self.__tl = False
+        if epen:
+            word = self.__epenthesis(word)
         if self.__ipa:
             self.__vowels += 'jw'
             self.__close += 'jw'
-        if exceptions:
+        if exceptions > 0:
+            if exceptions > 1:
+                self.__hiatus = True
+            else:
+                self.__hiatus = False
             self.__word = self.__make_exceptions(word)
             self.__word = self.__latin(self.__word)
         else:
@@ -19,7 +30,11 @@ class Syllabification:
         self.syllables = self.__syllabify(self.__word)
         self.stress = stressed_s(self.syllables)
 
+
     def __make_exceptions(self, word):
+        caparros = {'fie':'fi_e', 'sua':'su_a', 'rui': 'ru_i'}
+        if self.__hiatus and any(word.startswith(x) for x in caparros):
+            word = word.replace(word[:3], caparros[word[:3]])
         from importlib import resources
         lines = resources.read_text('silabeador', 'exceptions.lst')
         nouns = lines.splitlines()
@@ -28,6 +43,21 @@ class Syllabification:
             word = re.sub(rf'{noun[0]}', rf'{noun[1]}', word)
         return word
 
+    @staticmethod
+    def __epenthesis(word):
+        liquidae = ('sch', 'sc', 'st', 'sp', 'sf','sb', 'sm', 'sn')
+        if word.startswith(liquidae):
+            for onset in liquidae:
+                if word.startswith(onset):
+                    lonset = len(onset)
+                    if word[len(onset)] in 'aeiouáéíóúrl':
+                        onset = 'es_' + onset[1:]
+                    else:
+                        onset = 'e'+onset+'_'
+                    word = onset + word[lonset:]
+                    break
+        return word
+
     def __latin(self, verbum):
         flexiones = ('um', 'em', 'at', 'ant', 'it', 'unt', 'am')
         # 'int', 'ent', it', 'et', 'at', 'ur' 'int', 'ent'
@@ -77,38 +107,38 @@ class Syllabification:
             word = ''.join([letter if letter not in foreign_lig
                         else foreign_lig[letter] for letter in letters])
             slbs = self.__split(word)
-            slbs = self.__join(slbs, self.__h)
+            slbs = self.__join(slbs)
             letters = [x.strip() for x in slbs]
         return letters
 
-    def __split(self, letters, word = []):
-        dipht = re.findall(rf'(?:[qg][wuü](?:[eé](?:h*[{self.__close}])'
+    def __split(self, letters= '', word = []):
+        dipht = re.search(rf'(?:[qg][wuü](?:[eé](?:h*[{self.__close}])'
                            '{,1}|i(?:h*[aeoáéó]){,1}|í)|'
                            fr'[{self.__close}](?:h*[aáoóeéi])(?:h*[{self.__close}])'
                            '{,1}|'
                            rf'[aáoóeéií](?:h*[{self.__close}]))\b', letters)
         digraph = ('ll', 'ch', 'rr')
         if dipht:
-            dipht = dipht[0].strip('gq')
+            dipht = dipht.group().strip('gq')
             word = self.__split(letters.removesuffix(dipht), [dipht]+ word)
-        #elif letters.endswith('_'):
-        #    word = self.__split(letters[:-1], word)
         elif letters.endswith(digraph):
             word = self.__split(letters[:-2], [letters[-2:]] + word)
         elif letters:
             word = self.__split(letters[:-1], [letters[-1]]+ word)
         return word
 
-    def __join(self, letters, h):
+    def __join(self, letters):
         indivisible_onset = ('pl', 'bl', 'fl', 'cl', 'kl', 'gl', 'll',
                              'pr', 'br', 'fr', 'cr', 'kr', 'gr', 'rr',
                              'dr', 'tr', 'ch', 'dh', 'rh', 'th',
                              'βl', 'ɣl',
                              'βɾ', 'pɾ', 'fɾ', 'kɾ', 'gɾ', 'ɣɾ', 'dɾ', 'ðɾ',
                              'tɾ', 'bɾ', 'tʃ', 'gw', 'ɣw')
+        if self.__tl:
+            indivisible_onset += ('tl',)
         indivisible_coda = ('ns', 'bs', 'nz', 'βs', 'bz', 'βz', 'nd', 'rt',
-                            'st', 'ff', 'ls', 'zz', 'll', 'nt', 'rs', 'ɾs',
-                            'ch', 'nk', 'nc', 'lk', 'sh', 'nt')
+                            'st', 'ff', 'ls', 'lz', 'zz', 'll', 'nt', 'rs', 'ɾs',
+                            'ch', 'nk', 'nc', 'lk', 'sh', 'nt', 'sch', 'mp', 'rd')
         word = []
         onset = ''
         if self.__ipa:
@@ -131,7 +161,7 @@ class Syllabification:
                     onset += letter
                     if len(word) > 0:
                         media = len(onset) // 2
-                    if h and onset.endswith('h'):
+                    if self.__h and onset.endswith('h'):
                         media = 0
             elif len(onset) <= 1 or len(word) == 0:
                 word += [onset+letter]
@@ -160,7 +190,6 @@ class Syllabification:
                 word += [onset[media:] + letter]
                 onset = ''
         if onset:
-            print(word, onset)
             if onset.endswith('y') and len(onset) == 1:
                 word[-1] += onset
             elif onset.endswith('y'):
@@ -188,9 +217,9 @@ def stressed_s(slbs):
     return stress
 
 
-def syllabify(word, exceptions=True, ipa= False, h=False):
-    return Syllabification(word, exceptions, ipa, h).syllables
+def syllabify(word, exceptions=1, ipa= False, h=False, epen=False, tl=False):
+    return Syllabification(word, exceptions, ipa, h, epen, tl).syllables
 
 
-def tonica(word, exceptions=True, ipa= False, h=False):
-    return Syllabification(word, exceptions, ipa, h).stress
+def tonica(word, exceptions=1, ipa= False, h=False, epen=False, tl=False):
+    return Syllabification(word, exceptions, ipa, h, epen, tl).stress
